<template>
  <div class="container">
    <div class="card">
      <img src="/logo.png" alt="BhariPay Logo" class="logo" />
      <div v-if="validSession" id="payment-request-button"></div>
      <div v-if="validSession" class="separator">
        <span>OR</span>
      </div>
      <div v-if="validSession" class="payment-methods">
        <img src="/credit-cards.svg" alt="Credit Cards" class="payment-logo" />
      </div>
      <form v-if="validSession" @submit.prevent="submitPayment">
        <div class="name-fields">
          <input type="text" v-model="firstName" placeholder="First Name" class="input-field" required />
          <input type="text" v-model="lastName" placeholder="Last Name" class="input-field" required />
        </div>
        <input type="email" v-model="email" placeholder="Email Address" class="input-field email-field" required />
        <div id="card-element"><!-- Stripe Element will be inserted here --></div>
        <button type="submit" class="stripe-button">Pay GBP{{ amount }}</button>
        <div v-if="errorMessage" class="error-message">{{ errorMessage }}</div>
        <div v-if="loading" class="loading-spinner">
          <div class="spinner"></div>
        </div>
      </form>
      <div v-else>
        <p class="error-message">Redirecting...</p>
      </div>
    </div>
    <p class="transaction-notice" v-if="validSession">
      All transactions are secure and encrypted.
    </p>
    <img src="/logo.png" alt="Powered by" class="powered-by-logo" v-if="validSession" />
  </div>
</template>

<script>
import { loadStripe } from '@stripe/stripe-js'
import axios from 'axios'

export default {
  data() {
    return {
      stripe: null,
      elements: null,
      card: null,
      amount: null,
      firstName: '',
      lastName: '',
      email: '',
      loading: false,
      errorMessage: '',
      validSession: false,
      invoiceId: null
    }
  },
  async mounted() {
    document.addEventListener('contextmenu', (event) => event.preventDefault())
    
    const urlParams = new URLSearchParams(window.location.search)
    const token = urlParams.get('token')
    this.invoiceId = urlParams.get('invoiceId')

    if (!token) {
      this.redirectToHome()
      return
    }

    try {
      const response = await axios.post('/api/get-payment-details', { token })
      const { valid, amount, invoiceId } = response.data

      if (valid) {
        this.validSession = true;
        this.amount = amount;
        this.invoiceId = invoiceId;
        this.initializeStripe();
      } else {
        this.redirectToHome();
      }
    } catch (error) {
      this.redirectToHome();
    }
  },
  methods: {
    async initializeStripe() {
      this.stripe = await loadStripe(process.env.STRIPE_PUBLIC_KEY);
      this.elements = this.stripe.elements();
      this.card = this.elements.create('card', {
        style: {
          base: {
            color: '#32325d',
            fontFamily: 'Arial, sans-serif',
            fontSmoothing: 'antialiased',
            fontSize: '16px',
            '::placeholder': {
              color: '#aab7c4'
            }
          },
          invalid: {
            color: '#fa755a',
            iconColor: '#fa755a'
          }
        }
      });
      this.card.mount('#card-element');

      const paymentRequest = this.stripe.paymentRequest({
        country: 'GB',
        currency: 'gbp',
        total: {
          label: 'Total Amount',
          amount: this.amount * 100,
        },
        requestPayerName: true,
        requestPayerEmail: true,
      });

      const elements = this.stripe.elements();
      const prButton = elements.create('paymentRequestButton', {
        paymentRequest,
      });

      paymentRequest.canMakePayment().then((result) => {
        if (result) {
          prButton.mount('#payment-request-button');
        } else {
          document.getElementById('payment-request-button').style.display = 'none';
        }
      });
    },
    async submitPayment() {
      this.loading = true;
      this.errorMessage = '';

      try {
        const { paymentMethod, error: stripeError } = await this.stripe.createPaymentMethod({
          type: 'card',
          card: this.card,
          billing_details: {
            name: `${this.firstName} ${this.lastName}`,
            email: this.email
          }
        });

        if (stripeError) {
          this.errorMessage = stripeError.message;
          this.loading = false;
          return;
        }

        const { data } = await axios.post('/api/create-payment-intent', { 
          amount: this.amount * 100,
          invoiceId: this.invoiceId
        });

        const { error, paymentIntent } = await this.stripe.confirmCardPayment(data.clientSecret, {
          payment_method: paymentMethod.id
        });

        if (error) {
          this.errorMessage = error.message;
          this.loading = false;
          return;
        }

        if (paymentIntent.status === 'succeeded') {
          await axios.post('/api/confirm-payment', {
            paymentIntentId: paymentIntent.id,
            invoiceId: this.invoiceId
          });
          
          window.location.href = `${process.env.WHMCS_URL}/viewinvoice.php?id=${this.invoiceId}`;
        } else {
          this.errorMessage = 'Payment failed. Please try again.';
          this.loading = false;
        }
      } catch (error) {
        console.error('Error processing payment:', error);
        this.errorMessage = 'An error occurred while processing the payment. Please try again.';
        this.loading = false;
      }
    },
    redirectToHome() {
      this.validSession = false;
      setTimeout(() => {
        window.location.href = 'https://bhari.io';
      }, 3000);
    }
  }
}
</script>

<style scoped>
@import url('https://fonts.googleapis.com/css2?family=Arial:wght@400;700&display=swap');

.container {
  display: flex;
  flex-direction: column;
  align-items: center;
  justify-content: center;
  height: 100vh;
  background: linear-gradient(to bottom, #1e3c72, #2a5298);
  font-family: 'Arial', sans-serif;
  padding: 20px;
  box-sizing: border-box;
}

.card {
  background-color: white;
  padding: 20px;
  border-radius: 10px;
  text-align: center;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
  position: relative;
  width: 100%;
  max-width: 400px;
}

.logo {
  width: 150px;
  height: auto;
  margin-bottom: 20px;
}

#payment-request-button {
  margin-bottom: 20px;
}

.alternate-payment-methods {
  display: flex;
  justify-content: center;
  margin-bottom: 20px;
}

.separator {
  display: flex;
  align-items: center;
  justify-content: center;
  margin: 20px 0;
  position: relative;
  width: 100%;
  text-align: center;
}

.separator span {
  background-color: white;
  padding: 0 10px;
  position: relative;
  z-index: 1;
}

.separator::before, .separator::after {
  content: "";
  flex: 1;
  border-bottom: 1px solid #ccc;
  position: relative;
  top: -0.5em;
}

.payment-methods {
  display: flex;
  justify-content: center;
  align-items: center;
  margin-bottom: 20px;
}

.payment-logo {
  width: 150px;
  margin: 0 5px;
}

.tagline {
  font-size: 1rem;
  color: #555;
  margin: 10px 0 20px 0;
}

.amount-display {
  font-size: 1rem;
  font-family: 'Impact', sans-serif;
  color: #333;
  margin-bottom: 20px;
}

.name-fields {
  display: flex;
  justify-content: space-between;
  margin-bottom: 10px;
  gap: 10px;
}

.input-field {
  width: 48%;
  padding: 10px;
  border: 1px solid #ccc;
  border-radius: 5px;
  font-size: 14px;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
}

.email-field {
  width: 95%;
  margin-bottom: 20px;
}

#error-message {
  color: red;
  margin-top: 10px;
}

.loading-spinner {
  display: flex;
  justify-content: center;
  align-items: center;
  margin-top: 20px;
}

.loading-spinner .spinner {
  border: 8px solid #f3f3f3;
  border-top: 8px solid #00a65a;
  border-radius: 50%;
  width: 50px;
  height: 50px;
  animation: spin 1s linear infinite;
}

#card-element {
  margin-bottom: 20px;
  padding: 10px;
  border: 1px solid #ccc;
  border-radius: 5px;
  box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
}

@keyframes spin {
  0% { transform: rotate(0deg); }
  100% { transform: rotate(360deg); }
}

.stripe-button {
  background: linear-gradient(to bottom, #1e3c72, #2a5298);
  color: white;
  border: none;
  padding: 15px 0;
  cursor: pointer;
  border-radius: 5px;
  font-size: 1rem;
  transition: background-color 0.3s;
  width: 100%;
  margin-top: 20px;
}

.stripe-button:hover {
  background: linear-gradient(to bottom, #163359, #1f4170);
}

.transaction-notice {
  font-size: 0.8rem;
  color: white;
  font-weight: bold;
  text-align: center;
  margin-top: 20px;
  width: 80%;
  max-width: 500px;
}

.powered-by-logo {
  width: 150px;
  height: auto;
  margin-top: 10px;
}
</style>
